# Change Log
All notable changes to this project will be documented in this file.
 
The format is based on [Keep a Changelog](http://keepachangelog.com/).

## [0.1.4] - 2024-01-21 
 
### Added

### Changed
- Refactor 'load_page' method and add '_load_raw_page' method.
### Fixed

## [0.1.3] - 2024-01-20

### Added

### Changed
- Make 'fields' parameter mandatory in 'create_report' function.
- Update sklik_request method call in SklikApi.
### Fixed

## [0.1.0] - 2023-12-09
Initial version.